#include "historyinfowindow.h"

HistoryInfoWindow::HistoryInfoWindow(QWidget *parent) :
    QMainWindow(parent)
{
    QString set;
    setAttribute(Qt::WA_Maemo5StackedWindow);

    QWidget *widget = new QWidget();
    QVBoxLayout *vLayout = new QVBoxLayout();

    for(int i = 0; i < 9; i++)
    {
        set.setNum(i);
        lblSet[i] = new QLabel("Set " + set + ": No info.");
        vLayout->addWidget(lblSet[i]);
    }


    xml = new XML();

    widget->setLayout(vLayout);
    setCentralWidget(widget);
}

void HistoryInfoWindow::load(QString name, QString group)
{
    QList <QString> list;
    int j = 0;
    QString set;

    setWindowTitle(name + "/" + group);

    list = xml->getHistoryByExercise(name);

    while(!list.isEmpty())
    {
        set.setNum(j+1);
        if(group != "Cardio")
            lblSet[j]->setText("Set " + set + ": " + list.takeFirst() +" " +
                                list.takeFirst() + " reps - " + list.takeFirst());
        else
            lblSet[j]->setText("Set " + set + ": " + list.takeFirst() + " km on " +
                                list.takeFirst() + " - " + list.takeFirst());

        j++;
    }
}
